@@ -28,24 +28,58 @@
 #'  data(knz_001d)
 #'
 #'  # Calculate relative total turnover within replicates
-#'  total.res <- turnover(df=knz_001d,  replicate.var="subplot")
+#'  total.res <- turnover(df=knz_001d,  
+#'                time.var = "year", 
+#'                species.var = "species",
+#'                abundance.var = "abundance", 
+#'                replicate.var="subplot")
 #'  
 #'  # Calculate relative species appearances within replicates
-#'  appear.res <- turnover(df=knz_001d, replicate.var="subplot", metric="appearance")
+#'  appear.res <- turnover(df=knz_001d, 
+#'                time.var = "year", 
+#'                species.var = "species",
+#'                abundance.var = "abundance",  
+#'                replicate.var="subplot", 
+#'                metric="appearance")
 #'  
 #'  # Calculate relative species disappearances within replicates
-#'  disappear.res <- turnover(df=knz_001d, replicate.var="subplot", metric="disappearance")
+#'  disappear.res <- turnover(df=knz_001d, 
+#'                time.var = "year", 
+#'                species.var = "species",
+#'                abundance.var = "abundance", 
+#'                replicate.var="subplot", 
+#'                metric="disappearance")
 #'  
 #' @export
-turnover <- function(df, time.var="year", species.var="species", abundance.var="abundance", replicate.var=NA, metric="total") {
+turnover <- function(df, time.var, 
+                     species.var, 
+                     abundance.var, 
+                     replicate.var=NA, 
+                     metric="total") {
   
   if(is.na(replicate.var)){
+    
+    # check there unique species x time combinations
     check_single_onerep(df, time.var, species.var)
+    
+    # calculate turnover
     output <- turnover_allyears(df, time.var, species.var, abundance.var, metric)
+    
+    
     } else {
-      df[replicate.var]<-if(is.factor(df[[replicate.var]])){factor(df[[replicate.var]])} else {df[replicate.var] }
+      
+      # remove unused levels if replicate.var is a factor
+      df[replicate.var] <- if(is.factor(df[[replicate.var]])) {
+        factor(df[[replicate.var]])
+      } else {
+        df[replicate.var]
+      }
+      
+      # check unique species x time x replicate combinations
       check_single(df, time.var, species.var, replicate.var)
-      df<-df[order(df[[replicate.var]]),]
+      
+      # sort and apply turnover to all replicates
+      df <- df[order(df[[replicate.var]]),]
       X <- split(df, df[replicate.var])
       out <- lapply(X, FUN=turnover_allyears, time.var, species.var, abundance.var, metric)
       ID <- unique(names(out))
@@ -53,6 +87,8 @@ turnover <- function(df, time.var="year", species.var="species", abundance.var="
                   out, ID, SIMPLIFY = FALSE)
       output <- do.call("rbind", out)
     }
+  
+  # results
   row.names(output) <- NULL
   return(as.data.frame(output))
 }
@@ -77,12 +113,21 @@ turnover <- function(df, time.var="year", species.var="species", abundance.var="
 #'   \item{disappearance: }{ returns the number of disappearances in the second year relative to the total species richness across both years }
 #'   }
 #' @return output A dataframe containing the specificed turnover metric and year
-turnover_allyears <- function(df, time.var, species.var, abundance.var, metric=c("total", "disappearance","appearance")) {
-    metric = match.arg(metric) # for partial argument matching
+turnover_allyears <- function(df, 
+                              time.var, 
+                              species.var, 
+                              abundance.var, 
+                              metric=c("total", "disappearance","appearance")) {
+    
+    # allows partial argument matching
+    metric = match.arg(metric) 
   
+    # check time and abundance are numeric
     check_numeric(df, time.var, abundance.var)
-    df<-df[order(df[[time.var]]),]
-    df<-df[which(df[[abundance.var]]>0),]
+    
+    # sort and remove 0s
+    df <- df[order(df[[time.var]]),]
+    df <- df[which(df[[abundance.var]]>0),]
     
     ## split data by year
     templist <- split(df, df[[time.var]])
@@ -92,13 +137,15 @@ turnover_allyears <- function(df, time.var, species.var, abundance.var, metric=c
     t2 <- templist[-1]
     
     ## calculate turnover for across all time points
-    out <- Map(getturnover, t1, t2, species.var, metric)
-    output<-as.data.frame(unlist(out))
+    out <- Map(turnover_twoyears, t1, t2, species.var, metric)
+    output <- as.data.frame(unlist(out))
     names(output)[1] = metric
     
     ## add time variable column
     alltemp <- unique(df[[time.var]])
     output[time.var] =  alltemp[2:length(alltemp)]
+    
+    # results
     return(output)
 }
 
@@ -114,26 +161,43 @@ turnover_allyears <- function(df, time.var, species.var, abundance.var, metric=c
 #'  }
 #' @return output The specificed turnover metric
 
-getturnover <- function(d1, d2, species.var = "species", metric=c("total", "disappearance","appearance")){
-  metric = match.arg(metric) # for partial argument matching
+turnover_twoyears <- function(d1, d2, 
+                              species.var, 
+                              metric=c("total", "disappearance","appearance")){
   
+  # allows partial argument matching
+  metric = match.arg(metric)
+  
+  # create character vectors of unique species from each df
   d1spp <- as.character(unique(d1[[species.var]]))
   d2spp <- as.character(unique(d2[[species.var]]))
+  
+  # ID shared species
   commspp <- intersect(d1spp, d2spp)
+  
+  # count number not present in d2
   disappear <- length(d1spp)-length(commspp)
+  
+  # count number that appear in d2
   appear <- length(d2spp)-length(commspp)
+  
+  # calculate total richness
   totrich <- sum(disappear, appear, length(commspp))
-  if(metric == "total"){
+ 
+  # output based on metric 
+   if(metric == "total"){
         output <- ((appear+disappear)/totrich)
     } else {
-  if(metric=="appearance"){
+  if(metric == "appearance"){
         output <- appear/totrich
     } else {
-  if(metric=="disappearance"){
+  if(metric == "disappearance"){
         output <- disappear/totrich
       }
     }
     }
+  
+  # results
   return(output)
 }
 
